#
# spec file for package rubber
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rubber
Version:        1.4
Release:        3.2
Summary:        An automated system for building LaTeX documents
License:        GPL-2.0
Group:          Productivity/Publishing/TeX/Utilities
Url:            https://launchpad.net/rubber
Source:         https://launchpad.net/%{name}/trunk/%{version}/+download/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE rubber-makeinfo-unsupported-option.patch badshah400@gmail.com -- older versions of makeinfo does not support the "--info" option, patch it out to fix building on openSUSE <= 13.2.
Patch0:         rubber-makeinfo-unsupported-option.patch
BuildRequires:  makeinfo
BuildRequires:  python-devel >= 2.5
BuildRequires:  texinfo
Requires:       python >= 2.5
Requires:       python-base >= 2.5
Requires:       texlive-latex
Requires(post):  info
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%py_requires

%description
Rubber is a building system for LaTeX documents. It is based on a routine that
runs just as many compilations as necessary. The module system provides a
great flexibility that virtually allows support for any package with no user
intervention, as well as pre- and post-processing of the document. The
standard modules currently provide support for bibtex, dvips, dvipdfm, pdftex,
makeindex. A good number of standard packages are supported, including
graphics/graphicx (with automatic conversion between various formats and
Metapost compilation).

%prep
%setup -q
%if 0%{?suse_version} <= 1320
%patch0 -p1
%endif

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --mandir=%{_mandir} --infodir=%{_infodir} --docdir=%{_docdir}/%{name}

%post    
install-info %{_infodir}/rubber.info.gz %{_infodir}/dir

%postun    
install-info --delete %{_infodir}/rubber.info.gz %{_infodir}/dir

%files
%defattr(-,root,root)
%doc COPYING NEWS README
%{_bindir}/rubber
%{_bindir}/rubber-pipe
%{_bindir}/rubber-info
%{python_sitelib}/rubber/
%{python_sitelib}/rubber-%{version}-py%{py_ver}.egg-info
%{_mandir}/man1/rubber-info.1*
%{_mandir}/man1/rubber-pipe.1*
%{_mandir}/man1/rubber.1*
%{_infodir}/rubber.info.gz
%{_mandir}/fr/man1/*.gz
%{_docdir}/%{name}/

%changelog
* Mon Jul 18 2016 badshah400@gmail.com
- Add rubber-makeinfo-unsupported-option.patch to fix building
  on openSUSE <= 13.2, where makeinfo does not support the
  "--info" option.
* Mon Jul 18 2016 badshah400@gmail.com
- Update to version 1.4:
  + New distutils-based build & install scripts by Nicolas.
  + Report BibTeX / Biber errors more reliably.
  + We have support for embedding R code via knitr.
    http://yihui.name/knitr/
    Closes: https://bugs.launchpad.net/rubber/+bug/1422759
    Note that since R can run arbitrary external code, --unsafe
    must be given at the command line:
    rubber -d --unsafe paper.Rtex
    creates beautifully typeset PDF from your R script.
  + Support for PythonTeX package.  Also requires --unsafe if
    you want Rubber to invoke pythontex.
  + Rubber will no longer attempt to use jpeg2ps on its own, which
    has been superseded by sam2p.  (You can add it back by
    providing your own rules.ini.)
  + More refactoring, reducing the number of code paths to test and
    maintain.
  + Bugs fixed: lp#628150, lp#975376, lp#1090115.
- Also package HTML and PDF documentation in main package
  (documentation files are rather small and do not warrant a
  separate doc pkg).
- Drop conditionals and macro definitions for ancient distro
  versions.
- Add BuildRequires: texinfo, required for building PDF
  documentation.
* Sat Oct 27 2012 coolo@suse.com
- we also need to require info for %%post scripts
* Fri Sep  7 2012 coolo@suse.com
- add explicit buildrequire makeinfo
* Sat Sep 25 2010 badshah400@gmail.com
- Remove texlive texlive-bin texlive-bin-latex from Requires,
  texlive automatically pulls them in
- Lots of miscellaneous cleanup in the spec file
* Mon Aug  2 2010 badshah400@gmail.com
- spec file cleanup
* Sun Aug  1 2010 badshah400@gmail.com
- Intital package from upstream (development snapshot
  v20090819)
